Module platform

Module platform 

Platform detection and default library search paths.

Enums

OsFamily
Broad host-OS classification used by the loader.

Functions

driver_library_candidates
The most common libcuda filenames to probe, in preference order.
is_wsl2
true when running under the Windows Subsystem for Linux (WSL2).
library_search_paths
Directories the loader will search for NVIDIA shared libraries.
os_family
Detect the current OS family at runtime (cheap; branches on cfg!).
runtime_library_candidates
The most common libcudart filenames to probe, in preference order.
versioned_library_candidates
Build the list of probe filenames for a generic CUDA library, across the major versions baracuda targets. For example, versioned_library_candidates("cublas", "12", "11.0") yields libcublas.so.12, libcublas.so.11.0, libcublas.so on Linux and cublas64_12.dll, cublas64_11.dll, cublas64_110.dll on Windows.