Platform detection and default library search paths.
Enums
- OsFamily
- Broad host-OS classification used by the loader.
Functions
- driver_
library_ candidates - The most common
libcudafilenames to probe, in preference order. - is_wsl2
truewhen running under the Windows Subsystem for Linux (WSL2).- library_
search_ paths - Directories the loader will search for NVIDIA shared libraries.
- os_
family - Detect the current OS family at runtime (cheap; branches on
cfg!). - runtime_
library_ candidates - The most common
libcudartfilenames to probe, in preference order. - versioned_
library_ candidates - Build the list of probe filenames for a generic CUDA library, across the
major versions baracuda targets. For example,
versioned_library_candidates("cublas", "12", "11.0")yieldslibcublas.so.12, libcublas.so.11.0, libcublas.soon Linux andcublas64_12.dll, cublas64_11.dll, cublas64_110.dllon Windows.